pvr-testing2 xbmc discussion

Message ID 4C826E91.1050807@davis-family.info
State New
Headers

Commit Message

Rob Davis Sept. 4, 2010, 4:06 p.m. UTC
  On 12/05/10 14:36, Timothy D. Lenz wrote:
> Wish translators worked for that site. Created an account, but have to
> go through a translator site to read it and that breaks the login. Not
> that the translator works very well:
>
> "quasi as late Oster egg it gives nose fixed release of the Burn
> Plugins, in which larger and smaller errors are repaired. "
>
> On 5/12/2010 7:24 AM, Henning Pingel wrote:
>>
>> Am Mittwoch, den 12.05.2010, 15:27 +0200 schrieb Rob Davis
>> <rob@davis-family.info>:
>>> Does anyone know where this is happening now? I know the xbmc forum was
>>> down for a while, but this discussion never seemed to happen again
>>> afterwards.
>>
>> Hello Rob,
>>
>> Could you please specify in what kind of PVR discussion or what kind of
>> information you are interested?
>> I could point out a few threads to you but I'm confused about what you
>> want and why you ask here and not on the XBMC forum?
>>
>> The whole vdr-plugin-vnsiserver discussion is IMHO taking place at
>> www.vdr-portal.de ATM.

I have patched vnsi to get two ATSC and HD-PVR specific problems ironed 
out.
  

Patch

--- vdr-plugin-vnsiserver/demuxer.h	2010-06-03 13:53:13.000000000 -0500
+++ vdr-plugin-vnsiserver.working/demuxer.h	2010-09-03 15:07:25.000000000 -0500
@@ -31,6 +31,7 @@ 
 #define PRIVATE_STREAM1   0xBD
 #define PADDING_STREAM    0xBE
 #define PRIVATE_STREAM2   0xBF
+#define PRIVATE_STREAM3   0xFD
 #define AUDIO_STREAM_S    0xC0      /* 1100 0000 */
 #define AUDIO_STREAM_E    0xDF      /* 1101 1111 */
 #define VIDEO_STREAM_S    0xE0      /* 1110 0000 */
@@ -69,7 +70,7 @@ 
 
 inline bool PesIsPS1Packet(const uchar *p)
 {
-  return ((p)[3] == PRIVATE_STREAM1);
+  return ((p)[3] == PRIVATE_STREAM1 || (p)[3] == PRIVATE_STREAM3 );
 }
 
 inline bool PesIsPaddingPacket(const uchar *p)
--- vdr-plugin-vnsiserver/receiver.c	2010-08-07 16:45:04.000000000 -0500
+++ vdr-plugin-vnsiserver.working/receiver.c	2010-09-03 15:20:25.000000000 -0500
@@ -171,6 +171,7 @@ 
   {
     case 0x01: // ISO/IEC 11172 Video
     case 0x02: // ISO/IEC 13818-2 Video
+    case 0x80: // ATSC Video MPEG2 (DigiCypher?)
       LOGCONSOLE("cStreamdevPatFilter PMT scanner adding PID %d (%s)\n", stream.getPid(), psStreamTypes[stream.getStreamType()]);
       *type = stMPEG2VIDEO;
       return stream.getPid();
@@ -272,11 +273,11 @@ 
       break;
     default:
       /* This following section handles all the cases where the audio track
        * info is stored in PMT user info with stream id >= 0x80
        * we check the registration format identifier to see if it
        * holds "AC-3"
        */
-      if (stream.getStreamType() >= 0x80)
+      if (stream.getStreamType() >= 0x81)
       {
         bool found = false;
         for (SI::Loop::Iterator it; (d = stream.streamDescriptors.getNext(it)); )
@@ -272,11 +273,11 @@ 
     default:
       /* This following section handles all the cases where the audio track
-       * info is stored in PMT user info with stream id >= 0x80
+       * info is stored in PMT user info with stream id >= 0x81
        * we check the registration format identifier to see if it
        * holds "AC-3"